﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace BarSeriesHight
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			var series1Data = Data.GetData(1, 20, 30);
			var series2Data = Data.GetData(2, 30, 40);
			var series3Data = Data.GetData(3, 40, 50);

			DataContext = series1Data.Concat(series2Data).Concat(series3Data); 

			series1.ItemsSource = series1Data;
			series1.Brush = series1Data.First().Color;
			series2.ItemsSource = series2Data;
			series2.Brush = series2Data.First().Color;
			series3.ItemsSource = series3Data;
			series3.Brush = series3Data.First().Color;
		}
	}

	public class Data : INotifyPropertyChanged
	{
		private int open;
		private int close;
		private int high;
		private int low;
		private int value;
		private string label;
		private DateTime date;


		public DateTime Date
		{
			get { return date; }
			set
			{
				date = value;
				PropChanged("Date");
			}
		}


		public string Label
		{
			get { return label; }
			set
			{
				label = value;
				PropChanged("Label");
			}
		}

		public int Open
		{
			get { return open; }
			set
			{
				open = value;
				PropChanged("Open");
			}
		}

		public int Close
		{
			get { return close; }
			set
			{
				close = value;
				PropChanged("Close");
			}
		}

		public int High
		{
			get { return high; }
			set
			{
				high = value;
				PropChanged("High");
			}
		}

		public int Low
		{
			get { return low; }
			set
			{
				low = value;
				PropChanged("Low");
			}
		}

		public int Value
		{
			get { return value; }
			set
			{
				this.value = value;
				PropChanged("Value");
			}
		}

		private Brush _color;
		public Brush Color
		{
			get { return _color; }
			set
			{
				this._color = value;
				PropChanged("Color");
			}
		}

		public double Avarage
		{
			get
			{
				return (Open + Close + High + Low) / 4;
			}
		}

		static Random r = new Random();
		public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
		{
			ObservableCollection<Data> data = new ObservableCollection<Data>();
			int red = r.Next(0, byte.MaxValue + 1);
			int green = r.Next(0, byte.MaxValue + 1);
			int blue = r.Next(0, byte.MaxValue + 1);
			data.Add(new Data
			{
				Date = DateTime.Now.AddDays(points),
				Label = "Item " + points,
				Open = r.Next(rangeStart, rangeEnd),
				Close = r.Next(rangeStart, rangeEnd),
				High = r.Next(rangeStart, rangeEnd),
				Low = points,
				Color = new SolidColorBrush(System.Windows.Media.Color.FromRgb((byte) blue, (byte) green, (byte) red))
			});
			return data;
		}

		public event PropertyChangedEventHandler PropertyChanged;

		public void PropChanged(string name)
		{
			if (PropertyChanged != null)
				PropertyChanged(this, new PropertyChangedEventArgs(name));
		}
	}

}
